# Copyright (C) 2021-2024 MicroSys Electronics GmbH
# Author: Kay Potthoff <kay.potthoff@microsys.de>

FILESEXTRAPATHS:prepend := "${THISDIR}/${PN}:"
PATCHTOOL = "git"

SRC_URI:append = " file://linux.patch"

DEPENDS += "u-boot-tools-native dtc-native itsgen-native"

KERNEL_IMAGETYPE = "Image.gz"

UBOOT_DTB_LOADADDRESS ??= "0x90000000"

FDT_BLOB = "${@' --fdt '.join([os.path.join(d.getVar('B'), \
                              'arch/arm64/boot/dts/freescale', \
                              os.path.basename(dtb))+":load=${UBOOT_DTB_LOADADDRESS}" \
			      for dtb in d.getVar('KERNEL_DEVICETREE').split()])}"

LINUX_TOOLS ?= "leds usb"

do_compile:append() {

    itsgen --file ${B}/fitImage-${MACHINE}.its \
           --kernel ${B}/arch/arm64/boot/Image.gz:entry=${UBOOT_ENTRYPOINT} \
           --fdt ${FDT_BLOB} \
	   --no-hash

    mkimage -f ${B}/fitImage-${MACHINE}.its ${B}/fitImage-${MACHINE}.itb

    # Build Linux tools

    cd ${S}
    oe_runmake -C tools/ ${LINUX_TOOLS}
}

do_install:append() {

    install -d ${D}/boot

    install -m 0644 ${B}/fitImage-${MACHINE}.itb ${D}/boot

    ln -snf fitImage-${MACHINE}.itb ${D}/boot/fitImage.itb

    rm -f ${D}/boot/Image*

    # Install Linux tools
    # (the Makefile in tools/ doesn't install the tools with root ownership
    # therefore, we're doing this manually here)

    install -d -o root -g root ${D}${bindir}

    if ${@bb.utils.contains('LINUX_TOOLS', 'gpio', 'true', 'false', d)}; then
       install -m 0755 -o root -g root ${S}/tools/gpio/lsgpio ${D}${bindir}
       install -m 0755 -o root -g root ${S}/tools/gpio/gpio-event-mon ${D}${bindir}
       install -m 0755 -o root -g root ${S}/tools/gpio/gpio-hammer ${D}${bindir}
    fi

    if ${@bb.utils.contains('LINUX_TOOLS', 'led', 'true', 'false', d)}; then
        install -m 0755 -o root -g root ${S}/tools/leds/uledmon ${D}${bindir}
    fi

    if ${@bb.utils.contains('LINUX_TOOLS', 'usb', 'true', 'false', d)}; then
        install -m 0755 -o root -g root ${S}/tools/usb/testusb ${D}${bindir}
    fi

    if ${@bb.utils.contains('LINUX_TOOLS', 'spi', 'true', 'false', d)}; then
       install -m 0755 -o root -g root ${S}/tools/spi/spidev_test ${D}${bindir}
    fi
}

FILES:${KERNEL_PACKAGE_NAME}-image += "/boot/fitImage*"

COMPATIBLE_MACHINE = "(qoriq)"

PACKAGES += "${PN}-tools"

FILES:${PN}-tools += " \
   ${bindir} \
"

INSANE_SKIP:${PN}-tools = "ldflags debug-files"
